#!/usr/bin/env sh

echo "=> DÉBUT de l'installation :"


echo "=> Validation des DÉPENDENCES pour l'installation :"

# Vérifie si wget est installé
if ! hash wget 2>/dev/null; then
    echo " !! => wget n'est pas installé. Veuillez l'installer."
    exit 1
fi
echo "===> wget ... OK"

# Vérifie si zip est installé    
if ! hash zip 2>/dev/null; then
    echo "zip n'est pas installé. Veuillez l'installer."
    exit 1 
fi
echo "===> zip ... OK"

# Vérifier si sha256sum est installé
if ! hash sha256sum 2>/dev/null; then
     echo "sha256sum n'est pas installé. Veuillez l'installer."
     exit 1
fi
echo "===> sha256sum ... OK"

# download scut-latest.zip
echo "=> TÉLÉCHARGEMENT du programme :"
wget  -q https://git.bcmaison.cf/Outils/scut-reminder/raw/branch/main/scut-latest.zip

# Vérifie le code de retour de wget 
if [ $? -eq 0 ]; then
    echo "===> Téléchargement de scut-latest.zip réussi!"
else
    echo "!! => Erreur lors du téléchargement."
    exit 1
fi

# Vérifie que le fichier a bien été téléchargé
if [ -f "scut-latest.zip" ]; then
    echo "===> Fichier scut-latest.zip téléchargé avec succès."
else
    echo "!! => Échec du téléchargement du fichier scut-latest.zip."
    exit 1
fi

# Télécharge le fichier de checksum

wget -q https://git.bcmaison.cf/Outils/scut-reminder/raw/branch/main/scut-latest.zip.sha256

# Extrait le checksum du fichier
CHECKSUM=$(cat scut-latest.zip.sha256)

# Vérifie le checksum du fichier téléchargé
checksum_actuel=$(sha256sum scut-latest.zip | awk '{ print $1 }')

if [ "$CHECKSUM" == "$checksum_actuel" ]; then
    echo "===> Checksum validé - Fichier intègre."
else
    echo "!! => Erreur de checksum - Fichier corrompu."
    exit 1
fi

# unzip scut-<date>.zip in ~/.config/scut/
echo "=> INSTALLATION du programme :"

# Vérifier si le répertoire existe déjà
if [ ! -d "~/.config/scut/" ]; then
    # Le répertoire n'existe pas, on le crée
    mkdir -p ~/.config/scut
fi

# Désarchiver le zip dans ce dossier
unzip scut-latest.zip -d ~/.config/scut/

# Vérifier qu'au moins un fichier a été extrait
if [ $(ls -A ~/.config/scut/ | wc -l) -eq 0 ]; then
    echo "Aucun fichier extrait !" 
    exit 1
fi


echo "=> FIN de l'installation ! :-)"
